@@ -418,7 +418,7 @@ for l in loctypenames:
 
 def _q_transl_except(d):
     res = modification.parseString(d)
-    return (res[0], res[1])
+    return {"location": res[0], "acid": res[1]}
 
 _qual_default = lambda d: d.strip('"')
 _q_allele = _qual_default
